@@ -1,3 +1,6 @@
+use std::collections::HashMap;
+
+use serde_derive::Deserialize;
 use snafu::prelude::*;
 
 pub mod fs;
@@ -16,6 +19,16 @@ pub enum Error {
     InvalidUriScheme { scheme: String },
 }
 
+#[allow(non_camel_case_types)]
+#[derive(Deserialize, Clone, Debug, Eq, PartialEq)]
+#[serde(tag = "protcol")]
+#[serde(deny_unknown_fields)]
+pub enum IoOption {
+    http {
+        headers: Option<HashMap<String, String>>,
+    },
+}
+
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub enum BlobStoreType {
     Http,
