@@ -1,19 +1,20 @@
-use crate::table::{self, TableOptionExcel, TableSchema, TableSource};
-use arrow_schema::TimeUnit;
 use calamine::{open_workbook_auto, DataType as ExcelDataType, Range, Reader, Sheets};
 use datafusion::arrow::array::{
     ArrayRef, BooleanArray, DurationSecondArray, NullArray, PrimitiveArray, StringArray,
     TimestampSecondArray,
 };
 use datafusion::arrow::datatypes::{
-    DataType, Date32Type, Date64Type, Field, Float64Type, Int64Type, Schema,
+    DataType, Date32Type, Date64Type, Field, Float64Type, Int64Type, Schema, TimeUnit,
 };
 use datafusion::arrow::record_batch::RecordBatch;
+use datafusion::datasource::TableProvider;
 use snafu::prelude::*;
 use std::collections::HashMap;
 use std::sync::Arc;
 use std::vec;
 
+use crate::table::{self, LoadedTable, TableOptionExcel, TableSchema, TableSource};
+
 #[derive(Debug, Snafu)]
 pub enum Error {
     #[snafu(display("Failed to load Excel: {msg}"))]
@@ -45,7 +46,7 @@ impl<'a> ExcelSubrange<'a> {
         rows_range_end: Option<usize>,
         columns_range_start: Option<usize>,
         columns_range_end: Option<usize>,
-    ) -> ExcelSubrange {
+    ) -> ExcelSubrange<'a> {
         let rows_range_start = rows_range_start.unwrap_or(usize::MIN);
         let rows_range_end = rows_range_end
             .or(range.end().map(|v| v.0 as usize))
@@ -380,6 +381,17 @@ pub async fn to_mem_table(
     }
 }
 
+async fn to_datafusion_table(t: TableSource) -> Result<Arc<dyn TableProvider>, table::Error> {
+    Ok(Arc::new(to_mem_table(&t).await?))
+}
+
+pub async fn to_loaded_table(t: TableSource) -> Result<LoadedTable, table::Error> {
+    let reloader = Box::new(move || {
+        Box::pin(to_datafusion_table(t.clone())) as crate::table::TableRefresherOutput
+    });
+    Ok(LoadedTable::new(reloader().await?, reloader))
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -586,7 +598,7 @@ mod tests {
             infer_schema(&range, &TableOptionExcel::default(), &Some(table_schema)).unwrap();
 
         assert_eq!(
-            schema.all_fields(),
+            schema.flattened_fields(),
             vec![
                 &Field::new("float_column", DataType::Float64, true),
                 &Field::new("integer_column", DataType::Int64, true),
@@ -727,7 +739,7 @@ option:
         let rb = excel_range_to_record_batch(range, &TableOptionExcel::default(), shema).unwrap();
 
         assert_eq!(
-            rb.schema().all_fields(),
+            rb.schema().flattened_fields(),
             vec![
                 &Field::new("float_column", DataType::Float64, true),
                 &Field::new("integer_column", DataType::Int64, true),
