@@ -15,8 +15,8 @@ use arrow_flight::sql::{
     CommandGetDbSchemas, CommandGetExportedKeys, CommandGetImportedKeys, CommandGetPrimaryKeys,
     CommandGetSqlInfo, CommandGetTableTypes, CommandGetTables, CommandGetXdbcTypeInfo,
     CommandPreparedStatementQuery, CommandPreparedStatementUpdate, CommandStatementQuery,
-    CommandStatementSubstraitPlan, CommandStatementUpdate, Nullable, ProstMessageExt, Searchable,
-    SqlInfo, TicketStatementQuery, XdbcDataType,
+    CommandStatementSubstraitPlan, CommandStatementUpdate, DoPutPreparedStatementResult, Nullable,
+    ProstMessageExt, Searchable, SqlInfo, TicketStatementQuery, XdbcDataType,
 };
 use arrow_flight::{
     flight_service_server::FlightService, Action, FlightDescriptor, FlightEndpoint, FlightInfo,
@@ -24,7 +24,7 @@ use arrow_flight::{
 };
 use async_trait::async_trait;
 use base64::prelude::*;
-use columnq::arrow_schema::Schema;
+use columnq::datafusion::arrow::datatypes::Schema;
 use columnq::datafusion::arrow::ipc::writer::IpcWriteOptions;
 use columnq::datafusion::arrow::record_batch::RecordBatch;
 use columnq::datafusion::logical_expr::LogicalPlan;
@@ -800,7 +800,7 @@ impl<H: RoapiContext> FlightSqlService for RoapiFlightSqlService<H> {
         &self,
         _query: CommandPreparedStatementQuery,
         _request: Request<PeekableFlightDataStream>,
-    ) -> Result<Response<<Self as FlightService>::DoPutStream>, Status> {
+    ) -> Result<DoPutPreparedStatementResult, Status> {
         Err(Status::unimplemented(
             "do_put_prepared_statement_query not implemented",
         ))
